==> oci-java-sdk-shaded-full-3.40.0-sources.jar: com/oracle/bmc/vulnerabilityscanning/requests/GetHostCisBenchmarkScanResultRequest.java <==
/**
 * Copyright (c) 2016, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
package com.oracle.bmc.vulnerabilityscanning.requests;

import com.oracle.bmc.vulnerabilityscanning.model.*;
/**
 * <b>Example: </b>Click <a
 * href="https://docs.cloud.oracle.com/en-us/iaas/tools/java-sdk-examples/3.40.0/vulnerabilityscanning/GetHostCisBenchmarkScanResultExample.java.html"
 * target="_blank" rel="noopener noreferrer">here</a> to see how to use
 * GetHostCisBenchmarkScanResultRequest.
 */
@jakarta.annotation.Generated(value = "OracleSDKGenerator", comments = "API Version: 20210215")
public class GetHostCisBenchmarkScanResultRequest
        extends com.oracle.bmc.requests.BmcRequest<java.lang.Void> {

    /** unique host Cis benchmark scan identifier */
    private String hostCisBenchmarkScanResultId;

    /** unique host Cis benchmark scan identifier */
    public String getHostCisBenchmarkScanResultId() {
        return hostCisBenchmarkScanResultId;
    }
    /** The client request ID for tracing. */
    private String opcRequestId;

    /** The client request ID for tracing. */
    public String getOpcRequestId() {
        return opcRequestId;
    }

    public static class Builder
            implements com.oracle.bmc.requests.BmcRequest.Builder<
                    GetHostCisBenchmarkScanResultRequest, java.lang.Void> {
        private com.oracle.bmc.http.client.RequestInterceptor invocationCallback = null;
        private com.oracle.bmc.retrier.RetryConfiguration retryConfiguration = null;

        /** unique host Cis benchmark scan identifier */
        private String hostCisBenchmarkScanResultId = null;

        /**
         * unique host Cis benchmark scan identifier
         *
         * @param hostCisBenchmarkScanResultId the value to set
         * @return this builder instance
         */
        public Builder hostCisBenchmarkScanResultId(String hostCisBenchmarkScanResultId) {
            this.hostCisBenchmarkScanResultId = hostCisBenchmarkScanResultId;
            return this;
        }

        /** The client request ID for tracing. */
        private String opcRequestId = null;

        /**
         * The client request ID for tracing.
         *
         * @param opcRequestId the value to set
         * @return this builder instance
         */
        public Builder opcRequestId(String opcRequestId) {
            this.opcRequestId = opcRequestId;
            return this;
        }

        /**
         * Set the invocation callback for the request to be built.
         *
         * @param invocationCallback the invocation callback to be set for the request
         * @return this builder instance
         */
        public Builder invocationCallback(
                com.oracle.bmc.http.client.RequestInterceptor invocationCallback) {
            this.invocationCallback = invocationCallback;
            return this;
        }

        /**
         * Set the retry configuration for the request to be built.
         *
         * @param retryConfiguration the retry configuration to be used for the request
         * @return this builder instance
         */
        public Builder retryConfiguration(
                com.oracle.bmc.retrier.RetryConfiguration retryConfiguration) {
            this.retryConfiguration = retryConfiguration;
            return this;
        }

        /**
         * Copy method to populate the builder with values from the given instance.
         *
         * @return this builder instance
         */
        public Builder copy(GetHostCisBenchmarkScanResultRequest o) {
            hostCisBenchmarkScanResultId(o.getHostCisBenchmarkScanResultId());
            opcRequestId(o.getOpcRequestId());
            invocationCallback(o.getInvocationCallback());
            retryConfiguration(o.getRetryConfiguration());
            return this;
        }

        /**
         * Build the instance of GetHostCisBenchmarkScanResultRequest as configured by this builder
         *
         * <p>Note that this method takes calls to {@link
         * Builder#invocationCallback(com.oracle.bmc.http.client.RequestInterceptor)} into account,
         * while the method {@link Builder#buildWithoutInvocationCallback} does not.
         *
         * <p>This is the preferred method to build an instance.
         *
         * @return instance of GetHostCisBenchmarkScanResultRequest
         */
        public GetHostCisBenchmarkScanResultRequest build() {
            GetHostCisBenchmarkScanResultRequest request = buildWithoutInvocationCallback();
            request.setInvocationCallback(invocationCallback);
            request.setRetryConfiguration(retryConfiguration);
            return request;
        }

        /**
         * Build the instance of GetHostCisBenchmarkScanResultRequest as configured by this builder
         *
         * <p>Note that this method does not take calls to {@link
         * Builder#invocationCallback(com.oracle.bmc.http.client.RequestInterceptor)} into account,
         * while the method {@link Builder#build} does
         *
         * @return instance of GetHostCisBenchmarkScanResultRequest
         */
        public GetHostCisBenchmarkScanResultRequest buildWithoutInvocationCallback() {
            GetHostCisBenchmarkScanResultRequest request =
                    new GetHostCisBenchmarkScanResultRequest();
            request.hostCisBenchmarkScanResultId = hostCisBenchmarkScanResultId;
            request.opcRequestId = opcRequestId;
            return request;
            // new GetHostCisBenchmarkScanResultRequest(hostCisBenchmarkScanResultId, opcRequestId);
        }
    }

    /**
     * Return an instance of {@link Builder} that allows you to modify request properties.
     *
     * @return instance of {@link Builder} that allows you to modify request properties.
     */
    public Builder toBuilder() {
        return new Builder()
                .hostCisBenchmarkScanResultId(hostCisBenchmarkScanResultId)
                .opcRequestId(opcRequestId);
    }

    /**
     * Return a new builder for this request object.
     *
     * @return builder for the request object
     */
    public static Builder builder() {
        return new Builder();
    }

    @Override
    public String toString() {
        java.lang.StringBuilder sb = new java.lang.StringBuilder();
        sb.append("(");
        sb.append("super=").append(super.toString());
        sb.append(",hostCisBenchmarkScanResultId=")
                .append(String.valueOf(this.hostCisBenchmarkScanResultId));
        sb.append(",opcRequestId=").append(String.valueOf(this.opcRequestId));
        sb.append(")");
        return sb.toString();
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (!(o instanceof GetHostCisBenchmarkScanResultRequest)) {
            return false;
        }

        GetHostCisBenchmarkScanResultRequest other = (GetHostCisBenchmarkScanResultRequest) o;
        return super.equals(o)
                && java.util.Objects.equals(
                        this.hostCisBenchmarkScanResultId, other.hostCisBenchmarkScanResultId)
                && java.util.Objects.equals(this.opcRequestId, other.opcRequestId);
    }

    @Override
    public int hashCode() {
        final int PRIME = 59;
        int result = super.hashCode();
        result =
                (result * PRIME)
                        + (this.hostCisBenchmarkScanResultId == null
                                ? 43
                                : this.hostCisBenchmarkScanResultId.hashCode());
        result = (result * PRIME) + (this.opcRequestId == null ? 43 : this.opcRequestId.hashCode());
        return result;
    }
}

==> oci-java-sdk-shaded-full-3.48.0-sources.jar: com/oracle/bmc/vulnerabilityscanning/requests/GetHostCisBenchmarkScanResultRequest.java <==
/**
 * Copyright (c) 2016, 2024, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
package com.oracle.bmc.vulnerabilityscanning.requests;

import com.oracle.bmc.vulnerabilityscanning.model.*;
/**
 * <b>Example: </b>Click <a
 * href="https://docs.cloud.oracle.com/en-us/iaas/tools/java-sdk-examples/latest/vulnerabilityscanning/GetHostCisBenchmarkScanResultExample.java.html"
 * target="_blank" rel="noopener noreferrer">here</a> to see how to use
 * GetHostCisBenchmarkScanResultRequest.
 */
@jakarta.annotation.Generated(value = "OracleSDKGenerator", comments = "API Version: 20210215")
public class GetHostCisBenchmarkScanResultRequest
        extends com.oracle.bmc.requests.BmcRequest<java.lang.Void> {

    /** unique host Cis benchmark scan identifier */
    private String hostCisBenchmarkScanResultId;

    /** unique host Cis benchmark scan identifier */
    public String getHostCisBenchmarkScanResultId() {
        return hostCisBenchmarkScanResultId;
    }
    /** The client request ID for tracing. */
    private String opcRequestId;

    /** The client request ID for tracing. */
    public String getOpcRequestId() {
        return opcRequestId;
    }

    public static class Builder
            implements com.oracle.bmc.requests.BmcRequest.Builder<
                    GetHostCisBenchmarkScanResultRequest, java.lang.Void> {
        private com.oracle.bmc.http.client.RequestInterceptor invocationCallback = null;
        private com.oracle.bmc.retrier.RetryConfiguration retryConfiguration = null;

        /** unique host Cis benchmark scan identifier */
        private String hostCisBenchmarkScanResultId = null;

        /**
         * unique host Cis benchmark scan identifier
         *
         * @param hostCisBenchmarkScanResultId the value to set
         * @return this builder instance
         */
        public Builder hostCisBenchmarkScanResultId(String hostCisBenchmarkScanResultId) {
            this.hostCisBenchmarkScanResultId = hostCisBenchmarkScanResultId;
            return this;
        }

        /** The client request ID for tracing. */
        private String opcRequestId = null;

        /**
         * The client request ID for tracing.
         *
         * @param opcRequestId the value to set
         * @return this builder instance
         */
        public Builder opcRequestId(String opcRequestId) {
            this.opcRequestId = opcRequestId;
            return this;
        }

        /**
         * Set the invocation callback for the request to be built.
         *
         * @param invocationCallback the invocation callback to be set for the request
         * @return this builder instance
         */
        public Builder invocationCallback(
                com.oracle.bmc.http.client.RequestInterceptor invocationCallback) {
            this.invocationCallback = invocationCallback;
            return this;
        }

        /**
         * Set the retry configuration for the request to be built.
         *
         * @param retryConfiguration the retry configuration to be used for the request
         * @return this builder instance
         */
        public Builder retryConfiguration(
                com.oracle.bmc.retrier.RetryConfiguration retryConfiguration) {
            this.retryConfiguration = retryConfiguration;
            return this;
        }

        /**
         * Copy method to populate the builder with values from the given instance.
         *
         * @return this builder instance
         */
        public Builder copy(GetHostCisBenchmarkScanResultRequest o) {
            hostCisBenchmarkScanResultId(o.getHostCisBenchmarkScanResultId());
            opcRequestId(o.getOpcRequestId());
            invocationCallback(o.getInvocationCallback());
            retryConfiguration(o.getRetryConfiguration());
            return this;
        }

        /**
         * Build the instance of GetHostCisBenchmarkScanResultRequest as configured by this builder
         *
         * <p>Note that this method takes calls to {@link
         * Builder#invocationCallback(com.oracle.bmc.http.client.RequestInterceptor)} into account,
         * while the method {@link Builder#buildWithoutInvocationCallback} does not.
         *
         * <p>This is the preferred method to build an instance.
         *
         * @return instance of GetHostCisBenchmarkScanResultRequest
         */
        public GetHostCisBenchmarkScanResultRequest build() {
            GetHostCisBenchmarkScanResultRequest request = buildWithoutInvocationCallback();
            request.setInvocationCallback(invocationCallback);
            request.setRetryConfiguration(retryConfiguration);
            return request;
        }

        /**
         * Build the instance of GetHostCisBenchmarkScanResultRequest as configured by this builder
         *
         * <p>Note that this method does not take calls to {@link
         * Builder#invocationCallback(com.oracle.bmc.http.client.RequestInterceptor)} into account,
         * while the method {@link Builder#build} does
         *
         * @return instance of GetHostCisBenchmarkScanResultRequest
         */
        public GetHostCisBenchmarkScanResultRequest buildWithoutInvocationCallback() {
            GetHostCisBenchmarkScanResultRequest request =
                    new GetHostCisBenchmarkScanResultRequest();
            request.hostCisBenchmarkScanResultId = hostCisBenchmarkScanResultId;
            request.opcRequestId = opcRequestId;
            return request;
            // new GetHostCisBenchmarkScanResultRequest(hostCisBenchmarkScanResultId, opcRequestId);
        }
    }

    /**
     * Return an instance of {@link Builder} that allows you to modify request properties.
     *
     * @return instance of {@link Builder} that allows you to modify request properties.
     */
    public Builder toBuilder() {
        return new Builder()
                .hostCisBenchmarkScanResultId(hostCisBenchmarkScanResultId)
                .opcRequestId(opcRequestId);
    }

    /**
     * Return a new builder for this request object.
     *
     * @return builder for the request object
     */
    public static Builder builder() {
        return new Builder();
    }

    @Override
    public String toString() {
        java.lang.StringBuilder sb = new java.lang.StringBuilder();
        sb.append("(");
        sb.append("super=").append(super.toString());
        sb.append(",hostCisBenchmarkScanResultId=")
                .append(String.valueOf(this.hostCisBenchmarkScanResultId));
        sb.append(",opcRequestId=").append(String.valueOf(this.opcRequestId));
        sb.append(")");
        return sb.toString();
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (!(o instanceof GetHostCisBenchmarkScanResultRequest)) {
            return false;
        }

        GetHostCisBenchmarkScanResultRequest other = (GetHostCisBenchmarkScanResultRequest) o;
        return super.equals(o)
                && java.util.Objects.equals(
                        this.hostCisBenchmarkScanResultId, other.hostCisBenchmarkScanResultId)
                && java.util.Objects.equals(this.opcRequestId, other.opcRequestId);
    }

    @Override
    public int hashCode() {
        final int PRIME = 59;
        int result = super.hashCode();
        result =
                (result * PRIME)
                        + (this.hostCisBenchmarkScanResultId == null
                                ? 43
                                : this.hostCisBenchmarkScanResultId.hashCode());
        result = (result * PRIME) + (this.opcRequestId == null ? 43 : this.opcRequestId.hashCode());
        return result;
    }
}
